@@ -1,6 +1,6 @@
 package swat;
 
-our $VERSION = 'v0.1.20';
+our $VERSION = 'v0.1.21';
 
 use base 'Exporter'; 
 
@@ -51,7 +51,7 @@ sub make_http_request {
 
     diag `head -c $debug_bytes $content_file` if $debug;
 
-    ok($st, "successfull response from $http_meth $url$path") unless $ignore_http_err;
+    ok($st, "successful response from $http_meth $url$path") unless $ignore_http_err;
 
     diag "data file: $content_file";
 
@@ -261,7 +261,7 @@ SWAT is Simple Web Application Test ( Tool )
     /home/vagrant/.swat/reports/google.ru/00.t ..
     # start swat for google.ru/
     # try num 2
-    ok 1 - successfull response from GET google.ru/
+    ok 1 - successful response from GET google.ru/
     # data file: /home/vagrant/.swat/reports/google.ru/content.GET.txt
     ok 2 - GET / returns 200 OK
     ok 3 - GET / returns Google
@@ -291,7 +291,7 @@ SWAT:
 
 =item *
 
-is very pragmatical tool designed for job to be done in a fast and simple way
+is very pragmatic tool designed for job to be done in a fast and simple way
 
 =item *
 
@@ -446,7 +446,7 @@ This is most usable type of entries you  may define at swat data file. I<It's ju
 
 Using regexps
 
-Regexps are check expresions with the usage of <perl regular expressions> instead of plain strings checks.
+Regexps are check expressions with the usage of <perl regular expressions> instead of plain strings checks.
 Everything started with C<regexp:> marker would be treated as perl regular expression.
 
     # this is example of regexp check
@@ -474,14 +474,14 @@ There are a I<lot of possibilities>! Please follow L<Test::More|search.cpan.org/
     HELLO WORLD
 
 
-    code: skip('next test is skipped',1) unless $ENV{'debug'} == 1  # confitionally skip this check
+    code: skip('next test is skipped',1) unless $ENV{'debug'} == 1  # conditionally skip this check
     HELLO SWAT
 
 
 =head1 Generators
 
-Swat entries generators is the way to I<create new swat entries on the fly>. Technically specaking it's just a perl code which should return an array reference:
-Generators are very close to perl expressions ( generators code is alos get evaled ) with maijor difference:
+Swat entries generators is the way to I<create new swat entries on the fly>. Technically speaking it's just a perl code which should return an array reference:
+Generators are very close to perl expressions ( generators code is also get evaled ) with maijor difference:
 
 Value returned from generator's code should be  array reference. The array is passed back to swat parser so it can create new swat entries from it. 
 
@@ -499,7 +499,7 @@ This generator will generate 3 swat entries:
 
 
 As you can guess an array returned by generator should contain I<perl strings> representing swat entries, here is another example:
-with generator producing still 3 swat entites 'foo', 'bar', 'baz' :
+with generator producing still 3 swat entities 'foo', 'bar', 'baz' :
 
 
     # Place this in swat date file
@@ -514,7 +514,7 @@ This generator will generate 3 swat entities:
     bar value
 
 
-There is no limit for you! Use any code you want with only requiment - it should return array reference. 
+There is no limit for you! Use any code you want with only requirement - it should return array reference. 
 What about to validate web application content with sqlite database entries?
 
     # Place this in swat data file
@@ -558,7 +558,7 @@ Here are some exmaples:
     ]
 
     code:                                                       \
-    if $ENV{'debug'} == 1  { # confitionally skip this check    \
+    if $ENV{'debug'} == 1  { # conditionally skip this check    \
         skip('next test is skipped',1)                          \ 
     } 
     HELLO SWAT
@@ -572,7 +572,7 @@ Follow L<http://perldoc.perl.org/functions/eval.html> to get more on this.
 
 =head1 PERL5LIB
 
-Swat adds B<$project_root_directory/lib> to PERL5LIB , so this is convient convenient to place here custom perl modules:
+Swat adds B<$project_root_directory/lib> to PERL5LIB , so this is convenient convenient to place here custom perl modules:
 
 
     example/my-app/lib/Foo/Bar/Baz.pm
@@ -580,6 +580,138 @@ Swat adds B<$project_root_directory/lib> to PERL5LIB , so this is convient conve
 As an example take a loot at examples/swat-generators-with-lib/ project
 
 
+=head1 Anatomy of swat 
+
+Once swat runs it goes through some steps to get job done. Here is description of such a steps executed in orders
+
+=head2 Run iterator over swat data files
+
+Swat iterator look for all files named get.txt or post.txt under project root directory. Actually this is simple bash find loop.
+
+=head2 Parse swat data file
+
+For every swat data file find by iterator parsing process starts. Swat parse data file line by line, at the end of such a process
+I<a list of Test::More asserts> is generated. Finally asserts list and other input parameters are serialized as Test::More test scenario 
+written into into proper *.t file.
+
+=head2 Give it a run by prove
+
+Once swat finish parsing all the swat data files there is a whole bunch of *.t files kept under a designated  temporary directory,
+thus every swat route maps into Test::More test file with the list of asserts. Now all is ready for prove run. Internally `prove -r `
+command is issued to run tests and generate TAP report. That is it.
+
+
+Below is example hwo this looks like
+
+=head3 project structure
+
+
+    vagrant@Debian-jessie-amd64-netboot:~/projects/swat$ tree examples/anatomy/
+    examples/anatomy/
+    ├── FOO
+    │    └── BARs
+    │    └── post.txt
+    └── FOOs
+        └── get.txt
+
+    3 directories, 2 files
+
+=head3 swat data files
+
+    # /FOOs 
+    FOO
+    FOO2
+    generator: | %w{ FOO3 FOO4 }|
+
+    # /FOO/BARs
+    BAR
+    BAR2
+    generator: | %w{ BAR3 BAR4 }|
+    code: skip('skip next 2 test',2);
+    BAR5
+    BAR6
+    BAR7
+
+
+=head3 Test::More Asserts list
+
+
+    # /FOOs/0.t
+    SKIP {
+        ok($status, "successful response from $http_meth $url/FOO") 
+        ok($status, "GET /FOOs returns FOO")
+        ok($status, "GET /FOOs returns FOO2")
+        ok($status, "GET /FOOs returns FOO3")
+        ok($status, "GET /FOOs returns FOO4")
+    }
+
+    # /FOO/BARs0.t
+    SKIP {
+        ok($status, "successful response from $http_meth $url/FOO/BARs") 
+        ok($status, "GET /FOO/BARs returns BAR")
+        ok($status, "GET /FOO/BARs returns BAR")
+        ok($status, "GET /FOO/BARs returns BAR3")
+        ok($status, "GET /FOO/BARs returns BAR4")
+        skip('skip next 2 test',2);
+        ok($status, "GET /FOO/BARs returns BAR5")
+        ok($status, "GET /FOO/BARs returns BAR6")
+        ok($status, "GET /FOO/BARs returns BAR7")
+    }
+
+=head1 Hooks
+
+Hooks are files containing any perl code to be `required` into the beginning of every swat test. There are 2 types of hooks:
+
+=over 
+
+=item *
+
+B<project based hooks>
+
+File located at C<$project_root_directory/hook.pm>. Project based hooks are applied for every route in project and
+could be used for I<project initialization>. For example one could define generators here:
+
+    # place this in hook.pm file:
+    sub list1 { | %w{ foo bar baz } | }
+    sub list2 { | %w{ red green blue } | }
+
+
+    # now we could use it in swat data file
+    generator:  list() 
+    generator:  list2()    
+
+=item *
+
+B<route based hooks>
+
+File located at C<$project_root_directory/$route_directory/hook.pm>. Routes based hook are route specific hooks and
+could be used for I<route initialization>. For example one could define route specific generators here:
+
+    # place this in hook.pm file:
+    # notices that we could tell GET from POST http methods here:
+
+    sub list1 { 
+
+        my $list;
+
+        if ($method eq 'GET') {
+            $list = | %w{ GET_foo GET_bar GET_baz } | 
+        }elsif($method eq 'POST'){
+            $list = | %w{ POST_foo POST_bar POST_baz } | 
+        }else{
+            die "method $method is not supported"
+        }
+        $list;
+    }
+
+
+    # now we could use it in swat data file
+    generator:  list() 
+
+
+
+=back
+
 =head1 Post requests
 
 Name swat data file as post.txt to make http POST requests.
@@ -775,13 +907,13 @@ See also L<"Prove settings"> section.
 
 Swat is shipped as cpan package, once it's installed ( see L</"Install swat"> section ) you have a command line tool called B<swat>, this is usage info on it:
 
-    swat project_root_dir|swat_package URL <prove settings>
+    swat <project_root_dir|swat_package> <host:port> <prove settings>
 
 =over
 
 =item *
 
-B<URL> - is base url for web application you run tests against, you need defined routes which will be requested against URL, see DSL section.
+B<host> - is base url for web application you run tests against, you also have to define swat routes, see DSL section.
 
 
 =item *
@@ -813,7 +945,7 @@ C<-q -s> -  run tests in random and quite mode
 
 =head1 Swat Packages
 
-Swat packages is distributable archives of swat tests. It's easy to create your own swat packages and share with other. 
+Swat packages is portable archives of swat tests. It's easy to create your own swat packages and share with other. 
 
 This is mini how-to on creating swat packages:
 
